==> mobile_pos-1.1.1.tar.gz: lib/src/views/terminal/widget/disable_terminal_sheet.dart <==
// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';

class DisableTerminalSheet extends StatefulWidget {
  final TerminalModel model;
  const DisableTerminalSheet({super.key, required this.model});

  @override
  State<DisableTerminalSheet> createState() => _DisableTerminalSheetState();
}

class _DisableTerminalSheetState extends State<DisableTerminalSheet> {
  final titleController = TextEditingController();
  @override
  void initState() {
    titleController.text = widget.model.tidLabel ?? "";
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding) +
          EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          const Gap(16),
          const RavenPayBottomSheetCapsule(),
          const Gap(24),
          Row(
            children: [
              Expanded(
                child: Text(
                  "Disable Terminal",
                  style: headling1.copyWith(fontSize: 20),
                ),
              ),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: const RoundedItemContainer(asset: "cancel_icon.png"),
              )
            ],
          ),
          const Gap(12),
          Text(
              "Are you sure you want to disable this terminal, you won’t receive any payment on this terminal and you would need to contact the support to reactivate this terminal, confirm to proceed",
              style: subtitle2.copyWith(
                  fontSize: 14, fontWeight: FontWeight.w400)),
          const Gap(44),
          RavenPayButton(
              buttonText: "Proceed",
              buttonColor: AppColors.ravenRed,
              onPressed: () async {
                Navigator.pop(context);
              }),
          const Gap(30),
        ],
      ),
    );
  }
}

==> mobile_pos-2.0.0.tar.gz: lib/src/views/terminal/widget/disable_terminal_sheet.dart <==
// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_terminal_details.dart';

class DisableTerminalSheet extends StatefulWidget {
  final TerminalModel model;
  const DisableTerminalSheet({super.key, required this.model});

  @override
  State<DisableTerminalSheet> createState() => _DisableTerminalSheetState();
}

class _DisableTerminalSheetState extends State<DisableTerminalSheet> {
  final titleController = TextEditingController();
  @override
  void initState() {
    titleController.text = widget.model.tidLabel ?? "";
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding) +
          EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          const Gap(16),
          const RavenPayBottomSheetCapsule(),
          const Gap(24),
          Row(
            children: [
              Expanded(
                child: Text(
                  "Disable Terminal",
                  style: headling1.copyWith(fontSize: 20),
                ),
              ),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: const RoundedItemContainer(asset: "cancel_icon.png"),
              )
            ],
          ),
          const Gap(12),
          Text(
              "Are you sure you want to disable this terminal, you won’t receive any payment on this terminal and you would need to contact the support to reactivate this terminal, confirm to proceed",
              style: subtitle2.copyWith(
                  fontSize: 14, fontWeight: FontWeight.w400)),
          const Gap(44),
          RavenPayButton(
              buttonText: "Proceed",
              buttonColor: AppColors.ravenRed,
              onPressed: () async {
                Navigator.pop(context);
              }),
          const Gap(30),
        ],
      ),
    );
  }
}
